@@ -13,22 +13,23 @@
 # limitations under the License. 
 
 import base64
-import json
 import os
 import requests
-_DEFAULT_TIMEOUT = 30
+import liboidcagent as agent
+_DEFAULT_TIMEOUT = 60
 
 """ Generic http request """
 def make_request(c , path, method, **kwargs):
 
+    headers = get_headers(c)  
+
     if "timeout" in kwargs.keys() and kwargs["timeout"]: 
         timeout = kwargs["timeout"]
-        print("timeout set to: ", timeout)
     else: 
         timeout = _DEFAULT_TIMEOUT
 
     url = c.endpoint+path
-    headers = get_headers(c)  
+    
     if method in ["post", "put"]:
         if "token" in kwargs.keys() and kwargs["token"]: 
             headers = get_headers_with_token(kwargs["token"])
@@ -43,11 +44,17 @@ def make_request(c , path, method, **kwargs):
     result.raise_for_status()
     return result
 
-""" Function to generate headers with basic authentication """
+""" Function to generate headers with basic authentication or OIDC """
 def get_headers(c):
-    usr_pass_as_bytes = bytes(c.user+":"+c.password,"utf-8")
-    usr_pass_base_64 = base64.b64encode(usr_pass_as_bytes).decode("utf-8")
-    return {"Authorization": "Basic "+ usr_pass_base_64}
+    if c._AUTH_TYPE == "basicauth":
+        usr_pass_as_bytes = bytes(c.user+":"+c.password,"utf-8")
+        usr_pass_base_64 = base64.b64encode(usr_pass_as_bytes).decode("utf-8")
+        return {"Authorization": "Basic "+ usr_pass_base_64}
+    if c._AUTH_TYPE == "oidc-agent":
+        token = agent.get_access_token(c.shortname)
+        return get_headers_with_token(token)
+    if c._AUTH_TYPE == "oidc":
+        return get_headers_with_token(c.oidc_token)
 
 """ Function to generate headers with token auth """
 def get_headers_with_token(token):
@@ -104,4 +111,4 @@ def decode_output(output, file_path):
         write_text_file(output,file_path)
         return
 
- 
\ No newline at end of file
+ 
